@@ -1,30 +1,30 @@
 from typing import List, Optional
 
-from pydantic import BaseModel
+from pydantic import BaseModel, Field
 
 from .commands import CommandContribution
-
-# from .configuration import JsonSchemaObject
-from .io import ReaderContribution, WriterContribution
-
-# from .keybindings import KeyBindingContribution
 from .menus import MenusContribution
+from .readers import ReaderContribution
 from .sample_data import SampleDataContribution
 from .submenu import SubmenuContribution
 from .themes import ThemeContribution
 from .widgets import WidgetContribution
+from .writers import WriterContribution
 
 
 class ContributionPoints(BaseModel):
     commands: Optional[List[CommandContribution]]
-    themes: Optional[List[ThemeContribution]]
     readers: Optional[List[ReaderContribution]]
     writers: Optional[List[WriterContribution]]
-    sample_data: Optional[List[SampleDataContribution]]
     widgets: Optional[List[WidgetContribution]]
+    sample_data: Optional[List[SampleDataContribution]]
+    themes: Optional[List[ThemeContribution]]
 
-    menus: Optional[MenusContribution]
-    submenus: Optional[List[SubmenuContribution]]
+    menus: Optional[MenusContribution] = Field(None, hide_docs=True)
+    submenus: Optional[List[SubmenuContribution]] = Field(None, hide_docs=True)
 
     # configuration: Optional[JsonSchemaObject]
     # keybindings: Optional[List[KeyBindingContribution]]
+
+    class Config:
+        docs_exclude = {"menus", "submenus"}
