@@ -113,8 +113,8 @@ class PluginManifest(ImportExportModel):
         _validators.python_name
     )
 
-    contributions: Optional[ContributionPoints] = Field(
-        None,
+    contributions: ContributionPoints = Field(
+        default_factory=ContributionPoints,
         description="An object describing the plugin's "
         "[contributions](./contributions)",
     )
@@ -128,6 +128,9 @@ class PluginManifest(ImportExportModel):
         hide_docs=True,
     )
 
+    def __hash__(self):
+        return hash((self.name, self.package_version))
+
     @property
     def license(self) -> Optional[str]:
         return self.package_metadata.license if self.package_metadata else None
@@ -144,6 +147,10 @@ class PluginManifest(ImportExportModel):
     def author(self) -> Optional[str]:
         return self.package_metadata.author if self.package_metadata else None
 
+    @validator("contributions", pre=True)
+    def _coerce_none_contributions(cls, value):
+        return [] if value is None else value
+
     @root_validator
     def _validate_root(cls, values: dict) -> dict:
         # validate schema version
@@ -176,6 +183,9 @@ class PluginManifest(ImportExportModel):
                 )
             )
 
+        if not values.get("display_name"):
+            values["display_name"] = mf_name
+
         return values
 
     @classmethod
@@ -264,7 +274,13 @@ class PluginManifest(ImportExportModel):
                         pm = cls._from_entrypoint(ep, dist)
                         yield DiscoverResults(pm, ep, None)
                     except ValidationError as e:
-                        logger.warning(msg=f"Invalid schema {ep.value!r}")
+                        module_name, filename = ep.value.split(":")
+                        logger.warning(
+                            "Invalid schema for package %r, please run"
+                            " 'npe2 validate %s' to check for manifest errors.",
+                            module_name,
+                            module_name,
+                        )
                         yield DiscoverResults(None, ep, e)
                     except Exception as e:
                         logger.error(
