@@ -1,10 +1,11 @@
 import json
-from unittest.mock import MagicMock
+from unittest.mock import Mock
 
 import pytest
 
 from npe2 import PluginManager, PluginManifest
 from npe2.manifest.commands import CommandContribution
+from npe2.manifest.sample_data import SampleDataGenerator, SampleDataURI
 
 SAMPLE_PLUGIN_NAME = "my-plugin"
 
@@ -60,7 +61,7 @@ def test_writer_valid_layer_type_expressions(expr, uses_sample_plugin):
 
 
 def test_basic_iter_reader(uses_sample_plugin, plugin_manager: PluginManager, tmp_path):
-    assert list(plugin_manager.iter_compatible_readers("")) == []
+    assert not list(plugin_manager.iter_compatible_readers(""))
     reader = list(plugin_manager.iter_compatible_readers(tmp_path))[0]
     assert reader.command == f"{SAMPLE_PLUGIN_NAME}.some_reader"
 
@@ -92,8 +93,10 @@ def test_sample(uses_sample_plugin, plugin_manager: PluginManager):
     ctrbA, ctrbB = contribs
     # ignoring types because .command and .uri come from different sample provider
     # types... they don't both have "command" or "uri"
+    assert isinstance(ctrbA, SampleDataGenerator)
     assert ctrbA.command == f"{SAMPLE_PLUGIN_NAME}.generate_random_data"
     assert ctrbA.plugin_name == SAMPLE_PLUGIN_NAME
+    assert isinstance(ctrbB, SampleDataURI)
     assert ctrbB.uri == "https://picsum.photos/1024"
     assert isinstance(ctrbA.open(), list)
     assert isinstance(ctrbB.open(), list)
@@ -106,7 +109,7 @@ def test_directory_reader(uses_sample_plugin, plugin_manager: PluginManager, tmp
 
 def test_themes(uses_sample_plugin, plugin_manager: PluginManager):
     theme = list(plugin_manager.iter_themes())[0]
-    assert theme.label == "Monokai"
+    assert theme.label == "SampleTheme"
 
 
 def test_command_exec():
@@ -117,7 +120,7 @@ def test_command_exec():
         cmd = CommandContribution(id=cmd_id, title="a title")
         mf = PluginManifest(name="pkg", contributions={"commands": [cmd]})
         pm.register(mf)
-        some_func = MagicMock()
+        some_func = Mock()
         pm._command_registry.register(cmd_id, some_func)
         cmd.exec(args=("hi!",))
         some_func.assert_called_once_with("hi!")
